"""
Web Reader Mode

A Python package that extracts the main content from webpages and generates clean, reader-friendly HTML.
"""

from web_reader_mode.reader_mode import extract_content, download_image
from web_reader_mode.html_generator import generate_html

__version__ = "0.1.0"
